@@ -174,7 +174,7 @@ class PolymorphicList(Generic[T]):
     def remove_nth_occurrence(
             self, element: T,
             n: int) -> Union['NonEmptyList[T]', 'EmptyList[T]']:
-        """Removes the nth occurrence of a specified element from the list.
+        """Removes the nth occurrence of the specified element from the list.
         
         Args:
             element (T): The element to look for
@@ -188,6 +188,18 @@ class PolymorphicList(Generic[T]):
         """
         raise NotImplementedError()
 
+    def remove_all_occurrences(
+            self, element: T) -> Union['NonEmptyList[T]', 'EmptyList[T]']:
+        """Removes all occurrences of a specified element from the list.
+        
+        Args:
+            element (T): The element to look for
+        
+        Returns:
+            Union[NonEmptyList[T], EmptyList[T]]: The new head of the list after removing the element.
+        """
+        raise NotImplementedError()
+
     def remove_index(self,
                      index: int) -> Union['NonEmptyList[T]', 'EmptyList[T]']:
         """Removes the element at a given index if the index is valid
@@ -215,7 +227,7 @@ class PolymorphicList(Generic[T]):
         raise NotImplementedError()
 
     def get_tail(self) -> 'NonEmptyList[T]':
-        """Gets the last NonEmptyList element in the list.
+        """Gets the last NonEmptyList node in the list.
 
         Raises:
             ListIsEmptyError: raised since an EmptyList has no last element.
@@ -226,7 +238,7 @@ class PolymorphicList(Generic[T]):
         raise NotImplementedError()
 
     def get_nth_occurrence(self, element: T, n: int) -> 'NonEmptyList[T]':
-        """Gets the nth occurrence of the element
+        """Gets the NonEmptyList node with the nth occurrence of the element
 
         Args:
             element (T): The element to look for
@@ -241,7 +253,7 @@ class PolymorphicList(Generic[T]):
         raise NotImplementedError()
 
     def index_of(self, element: T) -> int:
-        """Finds the index of the first occurence of element param in the polymorphic list
+        """Finds the index of the first occurence of a specified element in the polymorphic list
 
         Args:
             element (T): The type T element to look for.
@@ -254,6 +266,17 @@ class PolymorphicList(Generic[T]):
         """
         raise NotImplementedError()
 
+    def count_occurrences(self, element: T) -> int:
+        """Counts the number of occurrences of element in the list.
+
+        Args:
+            element (T): The element to look for
+
+        Returns:
+            int: The num occurrences of element found
+        """
+        raise NotImplementedError()
+
 
 class NonEmptyList(PolymorphicList[T]):
     """Represents a NonEmptyList with a T type data, and a reference to the next node in the abstraction
@@ -455,6 +478,22 @@ class NonEmptyList(PolymorphicList[T]):
         self.length -= 1
         return self
 
+    def remove_all_occurrences(
+            self, element: T) -> Union['NonEmptyList[T]', 'EmptyList[T]']:
+        """Removes all occurrences of a specified element from the list.
+        
+        Args:
+            element (T): The element to look for
+        
+        Returns:
+            Union[NonEmptyList[T], EmptyList[T]]: The new head of the list after removing the element.
+        """
+        if (self.data == element):
+            return self.next.remove_all_occurrences(element)
+        else:
+            self.next = self.next.remove_all_occurrences(element)
+            return self
+
     def remove_index(self,
                      index: int) -> Union['NonEmptyList[T]', 'EmptyList[T]']:
         """Removes the element at a given index if the index is valid
@@ -539,6 +578,17 @@ class NonEmptyList(PolymorphicList[T]):
             return 1 + self.next.index_of(element)
         return 0
 
+    def count_occurrences(self, element: T) -> int:
+        """Counts the number of occurrences of element in the list.
+
+        Args:
+            element (T): The element to look for
+
+        Returns:
+            int: The num occurrences of element found
+        """
+        return (self.data == element) + self.next.count_occurrences(element)
+
 
 class EmptyList(PolymorphicList[T]):
     """Represents a EmptyList, the last node in the abstraction, which has no data or next pointer
@@ -689,6 +739,18 @@ class EmptyList(PolymorphicList[T]):
         raise ValueError(
             "There are fewer than `n` occurrences `element` in the list")
 
+    def remove_all_occurrences(
+            self, element: T) -> Union['NonEmptyList[T]', 'EmptyList[T]']:
+        """Removes all occurrences of a specified element from the list.
+        
+        Args:
+            element (T): The element to look for
+        
+        Returns:
+            Union[NonEmptyList[T], EmptyList[T]]: The new head of the list after removing the element.
+        """
+        return self
+
     def remove_index(self,
                      index: int) -> Union['NonEmptyList[T]', 'EmptyList[T]']:
         """Removes the element at a given index if the index is valid
@@ -752,3 +814,14 @@ class EmptyList(PolymorphicList[T]):
             int: The index of the first occurence of element if found
         """
         raise ValueError("`element` does not exist in the list")
+
+    def count_occurrences(self, element: T) -> int:
+        """Counts the number of occurrences of element in the list.
+
+        Args:
+            element (T): The element to look for
+
+        Returns:
+            int: The num occurrences of element found
+        """
+        return 0
\ No newline at end of file
